@@ -15,6 +15,7 @@
 
 class QString;
 class KCModuleInfo;
+class KDesktopFile;
 template<typename T> class QList;
 
 /**
@@ -89,12 +90,14 @@ public:
      */
     QList<MenuItem *> &children() const;
 
-    /**
-     * Returns the service object of this item, which contains useful information about it.
-     *
-     * @returns The service object of this item if it has been set.
-     */
-    KService::Ptr &service() const;
+    QString comment() const;
+    QString iconName() const;
+
+    bool isExternalAppModule() const;
+
+    bool isSystemsettingsCategory() const;
+    QString systemsettingsCategoryModule() const;
+    bool isSystemsettingsRootCategory() const;
 
     /**
      * Provides the KDE control module information item, which can be used to load control modules
@@ -142,6 +145,12 @@ public:
      */
     void setService(const KService::Ptr &service);
 
+    /**
+     * Constructs an item which resembles a category using the given filename.
+     * The properties are read using KConfig
+     */
+    void setCategoryConfig(const KDesktopFile &file);
+
     void setItem(const KCModuleInfo &item);
 
     MenuItem *descendantForModule(const QString &moduleName);
